==> mingw-w64-clang-aarch64-qt6-static-6.7.0-1-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6QuickTimelineBlendTrees/Qt6QuickTimelineBlendTreesTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::QuickTimelineBlendTrees" for configuration "Release"
set_property(TARGET Qt6::QuickTimelineBlendTrees APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickTimelineBlendTrees PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6QuickTimelineBlendTrees.a"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickTimelineBlendTrees )
list(APPEND _cmake_import_check_files_for_Qt6::QuickTimelineBlendTrees "${_IMPORT_PREFIX}/lib/libQt6QuickTimelineBlendTrees.a" )

# Import target "Qt6::QuickTimelineBlendTrees_resources_1" for configuration "Release"
set_property(TARGET Qt6::QuickTimelineBlendTrees_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickTimelineBlendTrees_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Timeline/BlendTrees/objects-Release/QuickTimelineBlendTrees_resources_1/.rcc/qrc_qmake_QtQuick_Timeline_BlendTrees_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickTimelineBlendTrees_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickTimelineBlendTrees_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Timeline/BlendTrees/objects-Release/QuickTimelineBlendTrees_resources_1/.rcc/qrc_qmake_QtQuick_Timeline_BlendTrees_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-qt6-static-6.8.0-3-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6QuickTimelineBlendTrees/Qt6QuickTimelineBlendTreesTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::QuickTimelineBlendTrees" for configuration "Release"
set_property(TARGET Qt6::QuickTimelineBlendTrees APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickTimelineBlendTrees PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6QuickTimelineBlendTrees.a"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickTimelineBlendTrees )
list(APPEND _cmake_import_check_files_for_Qt6::QuickTimelineBlendTrees "${_IMPORT_PREFIX}/lib/libQt6QuickTimelineBlendTrees.a" )

# Import target "Qt6::QuickTimelineBlendTrees_resources_1" for configuration "Release"
set_property(TARGET Qt6::QuickTimelineBlendTrees_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickTimelineBlendTrees_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Timeline/BlendTrees/objects-Release/QuickTimelineBlendTrees_resources_1/.qt/rcc/qrc_qmake_QtQuick_Timeline_BlendTrees_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickTimelineBlendTrees_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickTimelineBlendTrees_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Timeline/BlendTrees/objects-Release/QuickTimelineBlendTrees_resources_1/.qt/rcc/qrc_qmake_QtQuick_Timeline_BlendTrees_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
